@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
  * Copyright (C) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
- * Copyright (C) 2015-2016 Ragnar Thomsen <rthomsen6@gmail.com>
+ * Copyright (C) 2015-2017 Ragnar Thomsen <rthomsen6@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,8 +25,7 @@
 #include "ark_debug.h"
 #include "mainwindow.h"
 #include "batchextract.h"
-#include "kerfuffle/addtoarchive.h"
-#include "kdelibs4configmigrator.h"
+#include "addtoarchive.h"
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -35,8 +34,9 @@
 
 #include <KAboutData>
 #include <KCrash>
+#include <KDBusService>
+#include <Kdelibs4ConfigMigrator>
 #include <KLocalizedString>
-#include <kdbusservice.h>
 
 using Kerfuffle::AddToArchive;
 
@@ -67,7 +67,7 @@ int main(int argc, char **argv)
                          QStringLiteral(ARK_VERSION_STRING),
                          i18n("KDE Archiving tool"),
                          KAboutLicense::GPL,
-                         i18n("(c) 1997-2016, The Ark Developers"),
+                         i18n("(c) 1997-2017, The Ark Developers"),
                          QString(),
                          QStringLiteral("http://utils.kde.org/projects/ark")
     );
@@ -111,6 +111,10 @@ int main(int argc, char **argv)
                         QString(),
                         QStringLiteral("palm9744@kettering.edu"));
 
+    aboutData.addCredit(i18n("Vladyslav Batyrenko"),
+                        i18n("Advanced editing functionalities"),
+                        QString(),
+                        QStringLiteral("http://mvlabat.github.io/ark-gsoc-2016/"));
     aboutData.addCredit(i18n("Bryce Corkins"),
                         i18n("Icons"),
                         QStringLiteral("dbryce@attglobal.net"));
@@ -176,7 +180,7 @@ int main(int argc, char **argv)
     aboutData.processCommandLine(&parser);
 
     // This is needed to prevent Dolphin from freezing when opening an archive.
-    KDBusService dbusService(KDBusService::Multiple);
+    KDBusService dbusService(KDBusService::Multiple | KDBusService::NoExitOnFailure);
 
     // Session restoring.
     if (application.isSessionRestored()) {
