@@ -26,6 +26,7 @@
  */
 
 #include "propertiesdialog.h"
+#include "archive_kerfuffle.h"
 #include "ark_debug.h"
 #include "ui_propertiesdialog.h"
 
@@ -45,7 +46,7 @@ class PropertiesDialogUI: public QWidget, public Ui::PropertiesDialog
     Q_OBJECT
 
 public:
-    PropertiesDialogUI(QWidget *parent = 0)
+    PropertiesDialogUI(QWidget *parent = nullptr)
             : QWidget(parent) {
         setupUi(this);
     }
